summaryrefslogtreecommitdiffstats
path: root/config-db
diff options
context:
space:
mode:
authorOliver Tappe2006-08-17 21:36:39 +0200
committerOliver Tappe2006-08-17 21:36:39 +0200
commitb57cd6976eef41fda7d0db52016298c9bc85a67f (patch)
tree23ef7d2469262060b347ac061ed9a1853a334f2f /config-db
parent(partly) fixed uri_token function (file=tftp://... should work now), do (diff)
downloadcore-b57cd6976eef41fda7d0db52016298c9bc85a67f.tar.gz
core-b57cd6976eef41fda7d0db52016298c9bc85a67f.tar.xz
core-b57cd6976eef41fda7d0db52016298c9bc85a67f.zip
* added several new base-paths (private, public and shared)
* db-path default is now dependent on private base-path git-svn-id: http://svn.openslx.org/svn/openslx/trunk@307 95ad53e4-c205-0410-b2fa-d234c58c8868
Diffstat (limited to 'config-db')
-rw-r--r--config-db/ODLX/Basics.pm15
1 files changed, 13 insertions, 2 deletions
diff --git a/config-db/ODLX/Basics.pm b/config-db/ODLX/Basics.pm
index 5305f9b7..8825497d 100644
--- a/config-db/ODLX/Basics.pm
+++ b/config-db/ODLX/Basics.pm
@@ -28,17 +28,20 @@ my $loadedTranslationModule;
# this hash will hold the active odlx configuration,
# it is populated from config files and/or cmdline arguments:
%odlxConfig = (
- 'db-basepath' => "$FindBin::Bin",
'db-name' => 'odlx',
'db-type' => 'CSV',
'locale' => $ENV{LANG},
# TODO: may need to be improved in order to be portable
+ 'private-basepath=s' => '/var/lib/openslx',
+ 'public-basepath=s' => '/srv/openslx',
+ 'shared-basepath=s' => '/usr/share/openslx',
);
+$odlxConfig{'db-basepath'} = "$odlxConfig{'private-basepath'}/config-db",
# specification of cmdline arguments that are shared by all odlx-scripts:
my %odlxCmdlineArgs = (
'db-basepath=s' => \$odlxConfig{'db-basepath'},
# basic path to odlx database, defaults to path of running script
'db-datadir=s' => \$odlxConfig{'db-datadir'},
# data folder created under db-basepath, default depends on db-type
'db-spec=s' => \$odlxConfig{'db-spec'},
@@ -53,6 +56,14 @@ my %odlxCmdlineArgs = (
# locale to use for translations
'logfile=s' => \$odlxConfig{'locale'},
# file to write logging output to, defaults to STDERR
+ 'private-basepath=s' => \$odlxConfig{'private-basepath'},
+ # basic path to private data (which is accessible for clients and
+ # contains all data required for booting the clients)
+ 'public-basepath=s' => \$odlxConfig{'public-basepath'},
+ # basic path to public data (which contains database, vendorOSes
+ # and all local extensions [system specific scripts])
+ 'shared-basepath=s' => \$odlxConfig{'shared-basepath'},
+ # basic path to shared data (functionality templates and distro-specs)
'verbose-level=i' => \$odlxConfig{'verbose-level'},
# level of logging verbosity (0-3)
);
@@ -28,17 +28,20 @@ my $loadedTranslationModule;
my %odlxCmdlineArgs = (
'db-basepath=s' => \$odlxConfig{'db-basepath'},
- # basic path to odlx database, defaults to path of running script
+ # basic path to odlx database, defaults to "$private-basepath/config-db"
'db-datadir=s' => \$odlxConfig{'db-datadir'},
# data folder created under db-basepath, default depends on db-type